// SPDX-FileCopyrightText: 2017 - 2024 The Ginkgo authors
//
// SPDX-License-Identifier: BSD-3-Clause

#ifndef GKO_DPCPP_PRECONDITIONER_BATCH_PRECONDITIONERS_HPP_
#define GKO_DPCPP_PRECONDITIONER_BATCH_PRECONDITIONERS_HPP_


#include "core/matrix/batch_struct.hpp"
#include "core/preconditioner/batch_jacobi_helpers.hpp"
#include "dpcpp/preconditioner/batch_block_jacobi.hpp"
#include "dpcpp/preconditioner/batch_identity.hpp"
#include "dpcpp/preconditioner/batch_scalar_jacobi.hpp"


#endif  // GKO_DPCPP_PRECONDITIONER_BATCH_PRECONDITIONERS_HPP_
